# blade
This is a web scraper python lib currently used by Indexit project.

# Set up

## build image, run and enter container
```
bash scripts/start_dev.sh
```
##  function test
using ipython inside docker container to do functiont test.
